<?php namespace Anomaly\CartsModule\Cart;

use Anomaly\CartsModule\Cart\Command\DestroyCart;
use Anomaly\CartsModule\Cart\Command\GetCart;
use Anomaly\CartsModule\Item\Command\AddItem;
use Anomaly\CartsModule\Item\Command\RemoveItem;
use Anomaly\CartsModule\Item\Command\UpdateItem;
use Anomaly\StoreModule\Contract\CartInterface;
use Illuminate\Foundation\Bus\DispatchesJobs;

/**
 * Class CartService
 *
 * @link   http://pyrocms.com/
 * @author PyroCMS, Inc. <support@pyrocms.com>
 * @author Ryan Thompson <ryan@pyrocms.com>
 */
class CartService implements CartInterface
{

    use DispatchesJobs;

    /**
     * Return the cart instance.
     *
     * @return CartInterface
     */
    public function instance()
    {
        return $this->dispatch(new GetCart());
    }

    /**
     * Add a cart item.
     *
     * @param $item
     * @param int $quantity
     */
    public function add($item, $quantity = 1)
    {
        $this->dispatch(new AddItem($this->dispatch(new GetCart()), $item, $quantity));
    }

    /**
     * Remove a cart item.
     *
     * @param $id
     */
    public function remove($id)
    {
        $this->dispatch(new RemoveItem($this->dispatch(new GetCart()), $id));
    }

    /**
     * Update a cart item.
     *
     * @param $id
     * @param array $parameters
     */
    public function update($id, array $parameters)
    {
        $this->dispatch(new UpdateItem($this->dispatch(new GetCart()), $id, $parameters));
    }

    /**
     * Return the cart total.
     *
     * @return float
     */
    public function total()
    {
        /* @var CartInterface $cart */
        $cart = $this->dispatch(new GetCart());

        return $cart->total();
    }

    /**
     * Return the cart subtotal.
     *
     * @return float
     */
    public function subtotal()
    {
        /* @var CartInterface $cart */
        $cart = $this->dispatch(new GetCart());

        return $cart->subtotal();
    }

    /**
     * Return the number of
     * items in the cart.
     *
     * @return int
     */
    public function count()
    {
        /* @var CartInterface $cart */
        $cart = $this->dispatch(new GetCart());

        return $cart
            ->getItems()
            ->quantity();
    }

    /**
     * Destroy the cart.
     */
    public function destroy()
    {
        $this->dispatch(new DestroyCart());
    }
}
